@@ -23,10 +23,7 @@
 #include <glib.h>
 #include <pk-backend.h>
 
-/**
- * pk_backend_get_description:
- */
-gchar *
+const gchar *
 pk_backend_get_description (PkBackend *backend)
 {
 	return g_strdup ("Test NOP");
