@@ -536,6 +536,8 @@ pk_backend_job_signal_to_string (PkBackendJobSignal id)
 		return "Finished";
 	if (id == PK_BACKEND_SIGNAL_PACKAGE)
 		return "Package";
+	if (id == PK_BACKEND_SIGNAL_PACKAGES)
+		return "Packages";
 	if (id == PK_BACKEND_SIGNAL_ITEM_PROGRESS)
 		return "ItemProgress";
 	if (id == PK_BACKEND_SIGNAL_FILES)
@@ -562,6 +564,8 @@ pk_backend_job_signal_to_string (PkBackendJobSignal id)
 		return "LockedChanged";
 	if (id == PK_BACKEND_SIGNAL_UPDATE_DETAIL)
 		return "UpdateDetail";
+	if (id == PK_BACKEND_SIGNAL_UPDATE_DETAILS)
+		return "UpdateDetails";
 	if (id == PK_BACKEND_SIGNAL_CATEGORY)
 		return "Category";
 	return NULL;
@@ -960,6 +964,16 @@ pk_backend_job_package (PkBackendJob *job,
 			PkInfoEnum info,
 			const gchar *package_id,
 			const gchar *summary)
+{
+	pk_backend_job_package_full (job, info, package_id, summary, PK_INFO_ENUM_UNKNOWN);
+}
+
+void
+pk_backend_job_package_full (PkBackendJob *job,
+			     PkInfoEnum info,
+			     const gchar *package_id,
+			     const gchar *summary,
+			     PkInfoEnum update_severity)
 {
 	PkPackage *emitted_item;
 	gboolean ret;
@@ -978,6 +992,7 @@ pk_backend_job_package (PkBackendJob *job,
 		return;
 	}
 	pk_package_set_info (item, info);
+	pk_package_set_update_severity (item, update_severity);
 	pk_package_set_summary (item, summary);
 
 	/* already emitted? */
@@ -1020,6 +1035,62 @@ pk_backend_job_package (PkBackendJob *job,
 				   g_object_unref);
 }
 
+void
+pk_backend_job_packages (PkBackendJob *job,
+                         GPtrArray    *packages  /* (element-type PkPackage) */)
+{
+	g_return_if_fail (PK_IS_BACKEND_JOB (job));
+	g_return_if_fail (packages != NULL);
+
+	for (guint i = 0; i < packages->len; i++) {
+		PkPackage *item = g_ptr_array_index (packages, i);
+		PkInfoEnum info = pk_package_get_info (item);
+		PkPackage *emitted_item;
+
+		/* already emitted? */
+		emitted_item = g_hash_table_lookup (job->priv->emitted, pk_package_get_id (item));
+		if (emitted_item != NULL && pk_package_equal (emitted_item, item))
+			continue;
+
+		/* update the emitted package table */
+		g_hash_table_insert (job->priv->emitted,
+			             g_strdup (pk_package_get_id (item)),
+			             g_object_ref (item));
+
+		/* have we already set an error? */
+		if (job->priv->set_error) {
+			g_warning ("already set error: package %s", pk_package_get_id (item));
+			continue;
+		}
+
+		/* we automatically set the transaction status  */
+		if (info == PK_INFO_ENUM_DOWNLOADING)
+			pk_backend_job_set_status (job, PK_STATUS_ENUM_DOWNLOAD);
+		else if (info == PK_INFO_ENUM_UPDATING)
+			pk_backend_job_set_status (job, PK_STATUS_ENUM_UPDATE);
+		else if (info == PK_INFO_ENUM_INSTALLING)
+			pk_backend_job_set_status (job, PK_STATUS_ENUM_INSTALL);
+		else if (info == PK_INFO_ENUM_REMOVING)
+			pk_backend_job_set_status (job, PK_STATUS_ENUM_REMOVE);
+		else if (info == PK_INFO_ENUM_CLEANUP)
+			pk_backend_job_set_status (job, PK_STATUS_ENUM_CLEANUP);
+		else if (info == PK_INFO_ENUM_OBSOLETING)
+			pk_backend_job_set_status (job, PK_STATUS_ENUM_OBSOLETE);
+
+		/* we've sent a package for this transaction */
+		job->priv->has_sent_package = TRUE;
+	}
+
+	/* emit; this relies on the @packages array having ownership of all its
+	 * elements, as the job is asynchronous so they may be freed in their
+	 * original calling context */
+	if (packages->len > 0)
+		pk_backend_job_call_vfunc (job,
+					   PK_BACKEND_SIGNAL_PACKAGES,
+					   g_ptr_array_ref (packages),
+					   (GDestroyNotify) g_ptr_array_unref);
+}
+
 void
 pk_backend_job_update_detail (PkBackendJob *job,
 			      const gchar *package_id,
@@ -1087,6 +1158,29 @@ pk_backend_job_update_detail (PkBackendJob *job,
 				   g_object_unref);
 }
 
+void
+pk_backend_job_update_details (PkBackendJob *job,
+                               GPtrArray    *update_details  /* (element-type PkUpdateDetail) */)
+{
+	g_return_if_fail (PK_IS_BACKEND_JOB (job));
+	g_return_if_fail (update_details != NULL);
+
+	/* have we already set an error? */
+	if (job->priv->set_error) {
+		g_warning ("already set error: update_details");
+		return;
+	}
+
+	/* emit; this relies on the @update_details array having ownership of
+	 * all its elements, as the job is asynchronous so they may be freed in
+	 * their original calling context */
+	if (update_details->len > 0)
+		pk_backend_job_call_vfunc (job,
+					   PK_BACKEND_SIGNAL_UPDATE_DETAILS,
+					   g_ptr_array_ref (update_details),
+					   (GDestroyNotify) g_ptr_array_unref);
+}
+
 void
 pk_backend_job_require_restart (PkBackendJob *job,
 				PkRestartEnum restart,
@@ -1131,6 +1225,21 @@ pk_backend_job_details (PkBackendJob *job,
 			const gchar *description,
 			const gchar *url,
 			gulong size)
+{
+	pk_backend_job_details_full (job, package_id, summary, license, group,
+				     description, url, size, G_MAXUINT64);
+}
+
+void
+pk_backend_job_details_full (PkBackendJob *job,
+			     const gchar *package_id,
+			     const gchar *summary,
+			     const gchar *license,
+			     PkGroupEnum group,
+			     const gchar *description,
+			     const gchar *url,
+			     gulong size,
+			     guint64 download_size)
 {
 	g_autoptr(PkDetails) item = NULL;
 
@@ -1153,6 +1262,7 @@ pk_backend_job_details (PkBackendJob *job,
 		      "description", description,
 		      "url", url,
 		      "size", (guint64) size,
+		      "download-size", download_size,
 		      NULL);
 
 	/* emit */
