@@ -450,6 +450,14 @@ pk_engine_set_proxy_internal (PkEngine *engine, const gchar *sender,
 	guint uid;
 	g_autofree gchar *session = NULL;
 
+	if (!pk_dbus_connect (engine->priv->dbus, error)) {
+		g_set_error_literal (error,
+				     PK_ENGINE_ERROR,
+				     PK_ENGINE_ERROR_CANNOT_SET_PROXY,
+				     "failed to get the D-Bus proxy");
+		return FALSE;
+	}
+
 	/* get uid */
 	uid = pk_dbus_get_uid (engine->priv->dbus, sender);
 	if (uid == G_MAXUINT) {
@@ -594,6 +602,11 @@ pk_engine_is_proxy_unchanged (PkEngine *engine, const gchar *sender,
 	g_autofree gchar *no_proxy_tmp = NULL;
 	g_autofree gchar *pac_tmp = NULL;
 
+	if (!pk_dbus_connect (engine->priv->dbus, NULL)) {
+		g_warning ("failed to get the D-Bus proxy");
+		return FALSE;
+	}
+
 	/* get uid */
 	uid = pk_dbus_get_uid (engine->priv->dbus, sender);
 	if (uid == G_MAXUINT) {
@@ -632,6 +645,18 @@ pk_engine_is_proxy_unchanged (PkEngine *engine, const gchar *sender,
 	return TRUE;
 }
 
+static PolkitCheckAuthorizationFlags
+get_polkit_flags_for_dbus_invocation (GDBusMethodInvocation *invocation)
+{
+	PolkitCheckAuthorizationFlags flags = POLKIT_CHECK_AUTHORIZATION_FLAGS_NONE;
+	GDBusMessage *message = g_dbus_method_invocation_get_message (invocation);
+
+	if (g_dbus_message_get_flags (message) & G_DBUS_MESSAGE_FLAGS_ALLOW_INTERACTIVE_AUTHORIZATION)
+		flags |= POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION;
+
+	return flags;
+}
+
 static void
 pk_engine_set_proxy (PkEngine *engine,
 		     const gchar *proxy_http,
@@ -715,7 +740,7 @@ pk_engine_set_proxy (PkEngine *engine,
 	polkit_authority_check_authorization (engine->priv->authority, subject,
 					      "org.freedesktop.packagekit.system-network-proxy-configure",
 					      NULL,
-					      POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
+					      get_polkit_flags_for_dbus_invocation (context),
 					      NULL,
 					      (GAsyncReadyCallback) pk_engine_action_obtain_proxy_authorization_finished_cb,
 					      state);
@@ -1604,7 +1629,7 @@ pk_engine_offline_method_call (GDBusConnection *connection_, const gchar *sender
 		polkit_authority_check_authorization (engine->priv->authority, subject,
 						      "org.freedesktop.packagekit.trigger-offline-update",
 						      NULL,
-						      POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
+						      get_polkit_flags_for_dbus_invocation (invocation),
 						      NULL,
 						      pk_engine_offline_helper_cb,
 						      helper);
@@ -1618,7 +1643,7 @@ pk_engine_offline_method_call (GDBusConnection *connection_, const gchar *sender
 		polkit_authority_check_authorization (engine->priv->authority, subject,
 						      "org.freedesktop.packagekit.clear-offline-update",
 						      NULL,
-						      POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
+						      get_polkit_flags_for_dbus_invocation (invocation),
 						      NULL,
 						      pk_engine_offline_helper_cb,
 						      helper);
@@ -1645,7 +1670,7 @@ pk_engine_offline_method_call (GDBusConnection *connection_, const gchar *sender
 		polkit_authority_check_authorization (engine->priv->authority, subject,
 						      "org.freedesktop.packagekit.trigger-offline-update",
 						      NULL,
-						      POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
+						      get_polkit_flags_for_dbus_invocation (invocation),
 						      NULL,
 						      pk_engine_offline_helper_cb,
 						      helper);
@@ -1672,7 +1697,7 @@ pk_engine_offline_method_call (GDBusConnection *connection_, const gchar *sender
 		polkit_authority_check_authorization (engine->priv->authority, subject,
 						      "org.freedesktop.packagekit.trigger-offline-upgrade",
 						      NULL,
-						      POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
+						      get_polkit_flags_for_dbus_invocation (invocation),
 						      NULL,
 						      pk_engine_offline_helper_cb,
 						      helper);
@@ -1724,14 +1749,14 @@ pk_engine_on_bus_acquired_cb (GDBusConnection *connection,
 	PkEngine *engine = PK_ENGINE (user_data);
 	guint registration_id;
 	static const GDBusInterfaceVTable iface_daemon_vtable = {
-		pk_engine_daemon_method_call,
-		pk_engine_daemon_get_property,
-		NULL
+		.method_call = pk_engine_daemon_method_call,
+		.get_property = pk_engine_daemon_get_property,
+		.set_property = NULL
 	};
 	static const GDBusInterfaceVTable iface_offline_vtable = {
-		pk_engine_offline_method_call,
-		pk_engine_offline_get_property,
-		NULL
+		.method_call = pk_engine_offline_method_call,
+		.get_property = pk_engine_offline_get_property,
+		.set_property = NULL
 	};
 
 	/* save copy for emitting signals */
